package com.liang.controller;

import com.liang.common.annotation.LogAround;
import com.liang.entity.BaseMost;
import com.liang.service.BaseMostService;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * (BaseMost)表控制层
 *
 * @author makejava
 * @since 2023-03-04 11:25:23
 */
@Controller
@RequestMapping("baseMost")
public class BaseMostController {
    /**
     * 服务对象
     */
    @Resource
    private BaseMostService baseMostService;

    /**
     * 分页查询
     *
     * @param baseMost    筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    @GetMapping
    public ResponseEntity<Page<BaseMost>> queryByPage(BaseMost baseMost, PageRequest pageRequest) {
        return ResponseEntity.ok(this.baseMostService.queryByPage(baseMost, pageRequest));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    public ResponseEntity<BaseMost> queryById(@PathVariable("id") String id) {
        return ResponseEntity.ok(this.baseMostService.queryById(id));
    }

    /**
     * 新增数据
     *
     * @param baseMost 实体
     * @return 新增结果
     */
    @PostMapping
    public ResponseEntity<BaseMost> add(BaseMost baseMost) {
        return ResponseEntity.ok(this.baseMostService.insert(baseMost));
    }

    /**
     * 编辑数据
     *
     * @param baseMost 实体
     * @return 编辑结果
     */
    @PutMapping
    public ResponseEntity<BaseMost> edit(BaseMost baseMost) {
        return ResponseEntity.ok(this.baseMostService.update(baseMost));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */
    @DeleteMapping
    public ResponseEntity<Boolean> deleteById(String id) {
        return ResponseEntity.ok(this.baseMostService.deleteById(id));
    }

    @ApiOperation(value = "页面初始化", notes = "页面初始化")
    @RequestMapping(value = "/init", method = RequestMethod.GET)
    public String init() {
        return "basemost/list";
    }

    @LogAround("数据分页查询")
    @ApiOperation(value = "数据分页查询", notes = "数据分页查询")
    @ResponseBody
    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public Object list() {

        List<BaseMost> list = baseMostService.queryAll();

        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("code", 0);
        resultMap.put("msg", "");
        resultMap.put("count", list.size());
        resultMap.put("data", list);

        return resultMap;
    }
}

