package com.liang.controller;

import com.liang.common.annotation.LogAround;
import com.liang.entity.BaseTitle;
import com.liang.service.BaseTitleService;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * (BaseTitle)表控制层
 *
 * @author makejava
 * @since 2023-03-03 21:59:50
 */
@Controller
@RequestMapping("baseTitle")
public class BaseTitleController {
    /**
     * 服务对象
     */
    @Resource
    private BaseTitleService baseTitleService;

    /**
     * 分页查询
     *
     * @param baseTitle   筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    @GetMapping
    public ResponseEntity<Page<BaseTitle>> queryByPage(BaseTitle baseTitle, PageRequest pageRequest) {
        return ResponseEntity.ok(this.baseTitleService.queryByPage(baseTitle, pageRequest));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    public ResponseEntity<BaseTitle> queryById(@PathVariable("id") Object id) {
        return ResponseEntity.ok(this.baseTitleService.queryById(id));
    }

    /**
     * 新增数据
     *
     * @param baseTitle 实体
     * @return 新增结果
     */
    @PostMapping
    public ResponseEntity<BaseTitle> add(BaseTitle baseTitle) {
        return ResponseEntity.ok(this.baseTitleService.insert(baseTitle));
    }

    /**
     * 编辑数据
     *
     * @param baseTitle 实体
     * @return 编辑结果
     */
    @PutMapping
    public ResponseEntity<BaseTitle> edit(BaseTitle baseTitle) {
        return ResponseEntity.ok(this.baseTitleService.update(baseTitle));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */
    @DeleteMapping
    public ResponseEntity<Boolean> deleteById(Object id) {
        return ResponseEntity.ok(this.baseTitleService.deleteById(id));
    }

    @ApiOperation(value = "页面初始化", notes = "页面初始化")
    @RequestMapping(value = "/init", method = RequestMethod.GET)
    public String init() {
        return "basetitle/list";
    }

    @LogAround("数据分页查询")
    @ApiOperation(value = "数据分页查询", notes = "数据分页查询")
    @ResponseBody
    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public Object list() {

        List<BaseTitle> list = baseTitleService.queryAll();

        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("code", 0);
        resultMap.put("msg", "");
        resultMap.put("count", list.size());
        resultMap.put("data", list);

        return resultMap;
    }
}

