package com.liang.controller;

import com.github.pagehelper.PageInfo;
import com.liang.common.JsonTool;
import com.liang.common.base.BaseController;
import com.liang.common.base.BaseResult;
import com.liang.entity.StaMaterialcost;
import com.liang.service.StaMaterialcostService;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 材料费(StaMaterialcost)表控制层
 *
 * @author makejava
 * @since 2023-07-18 21:55:34
 */
@Controller
@RequestMapping("staMaterialcost")
public class StaMaterialcostController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private StaMaterialcostService staMaterialcostService;

    /**
     * 分页查询
     *
     * @param staMaterialcost 筛选条件
     * @param pageRequest     分页对象
     * @return 查询结果
     */
    @GetMapping
    public ResponseEntity<Page<StaMaterialcost>> queryByPage(StaMaterialcost staMaterialcost, PageRequest pageRequest) {
        return ResponseEntity.ok(this.staMaterialcostService.queryByPage(staMaterialcost, pageRequest));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    public ResponseEntity<StaMaterialcost> queryById(@PathVariable("id") Integer id) {
        return ResponseEntity.ok(this.staMaterialcostService.queryById(id));
    }

    /**
     * 新增数据
     *
     * @param staMaterialcost 实体
     * @return 新增结果
     */
    @PostMapping
    public ResponseEntity<StaMaterialcost> add(StaMaterialcost staMaterialcost) {
        return ResponseEntity.ok(this.staMaterialcostService.insert(staMaterialcost));
    }

    /**
     * 编辑数据
     *
     * @param staMaterialcost 实体
     * @return 编辑结果
     */
    @PutMapping
    public ResponseEntity<StaMaterialcost> edit(StaMaterialcost staMaterialcost) {
        return ResponseEntity.ok(this.staMaterialcostService.update(staMaterialcost));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */
    @DeleteMapping
    public ResponseEntity<Boolean> deleteById(Integer id) {
        return ResponseEntity.ok(this.staMaterialcostService.deleteById(id));
    }

    /**
     * 初始化列表
     *
     * @param zb
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/list/{zb}", method = RequestMethod.POST)
    public BaseResult list(@PathVariable Integer zb) {
        List<StaMaterialcost> list = staMaterialcostService.getClfList(zb);

        PageInfo<StaMaterialcost> pageinfo = new PageInfo<>(list);
        //取出查询结果
        List<StaMaterialcost> rows = pageinfo.getList();
        int total = (int) pageinfo.getTotal();
        Map<String, Object> result = new HashMap<>();
        result.put(RESULT_ROWS, rows);
        result.put(RESULT_TOTAL, total);

        return BaseResult.success(result);
    }

    /**
     * 新建数据
     *
     * @return
     */
    @RequestMapping(value = "/forAdd", method = RequestMethod.GET)
    public String forAdd() {
        return "materialcost/add";
    }

    /**
     * 批量保存
     *
     * @param data
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/batchInsert/{zb}", method = RequestMethod.POST)
    public BaseResult batchInsert(@RequestBody String data, @PathVariable Integer zb) {
        //删除
        staMaterialcostService.deleteByZb(zb);

        List<StaMaterialcost> expenseList = JsonTool.parseArray(data, StaMaterialcost.class);
        for (int i = 0; i < expenseList.size(); i++) {
            expenseList.get(i).setZb(zb);
        }
        if (expenseList.size() > 0) {
            int num = staMaterialcostService.insertBatch(expenseList);
            if (num == expenseList.size()) {
                return BaseResult.success("仪器设备使用费保存成功！");
            } else {
                return BaseResult.failure("仪器设备使用费保存失败！");
            }
        } else {
            return BaseResult.success("没有要保存的信息");
        }
    }

    /**
     * 编辑数据
     *
     * @return
     */
    @RequestMapping(value = "/forUpdate", method = RequestMethod.GET)
    public String forUpdate() {
        return "materialcost/update";
    }

    /**
     * 查看数据
     *
     * @return
     */
    @RequestMapping(value = "/forView", method = RequestMethod.GET)
    public String forView() {
        return "materialcost/view";
    }
}

