package com.liang.dao;

import com.liang.entity.StaExpertFee;
import com.liang.entity.StaIntellectualProperty;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 专家咨询费(StaExpertFeeDao)表数据库访问层
 */
public interface StaExpertFeeDao {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaExpertFee queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param staExpertFee 查询条件
     * @param pageable     分页对象
     * @return 对象列表
     */
    List<StaExpertFee> queryAllByLimit(StaExpertFee staExpertFee, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param staExpertFee 查询条件
     * @return 总行数
     */
    long count(StaExpertFee staExpertFee);

    /**
     * 新增数据
     *
     * @param staExpertFee 实例对象
     * @return 影响行数
     */
    int insert(StaExpertFee staExpertFee);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<StaExpertFee> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<StaExpertFee> entities);

    /**
     * 修改数据
     *
     * @param staExpertFee 实例对象
     * @return 影响行数
     */
    int update(StaExpertFee staExpertFee);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除专家咨询费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入专家咨询费
     *
     * @param entities
     * @return
     */
    int insertBatch(@Param("entities") List<StaExpertFee> entities);

    /**
     * 获取专家咨询费列表
     *
     * @return
     */
    List<StaExpertFee> getZjfList(Integer zb);

    List<StaExpertFee> queryByKyfh(String kyfh);

    /**
     * 项目报表专家费查询
     *
     * @param MC   项目名称
     * @param ZJXM 专家姓名
     * @param ZC   职称
     * @param QSRQ 创建起始日期
     * @param JZRQ 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchExpertFeeCost(Map map);
}
