package com.liang.dao;

import com.liang.entity.StaMaterial;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 材料费(StaMaterial)表数据库访问层
 */
public interface StaMaterialDao {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaMaterial queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param staMaterial 查询条件
     * @param pageable    分页对象
     * @return 对象列表
     */
    List<StaMaterial> queryAllByLimit(StaMaterial staMaterial, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param staMaterial 查询条件
     * @return 总行数
     */
    long count(StaMaterial staMaterial);

    /**
     * 新增数据
     *
     * @param staMaterial 实例对象
     * @return 影响行数
     */
    int insert(StaMaterial staMaterial);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<StaMaterial> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<StaMaterial> entities);

    /**
     * 修改数据
     *
     * @param staMaterial 实例对象
     * @return 影响行数
     */
    int update(StaMaterial staMaterial);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除材料费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入材料费
     *
     * @param entities
     * @return
     */
    int insertBatch(@Param("entities") List<StaMaterial> entities);

    /**
     * 获取材料费列表
     *
     * @return
     */
    List<StaMaterial> getList(Integer zb);

    /**
     * 统计报表（材料费）查询
     *
     * @param MC   项目名称
     * @param CLMC 材料名称
     * @param WLBM 物料编码
     * @param BZ   备注
     * @param QSRQ 创建起始日期
     * @param JZRQ 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchMaterialCost(Map map);
}
