package com.liang.dao;

import com.liang.entity.StaIntellectualProperty;
import com.liang.entity.StaMeetingFee;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 会议费(StaMeetingFee)表数据库访问层
 */
public interface StaMeetingFeeDao {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaMeetingFee queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param staMeetingFee 查询条件
     * @param pageable      分页对象
     * @return 对象列表
     */
    List<StaMeetingFee> queryAllByLimit(StaMeetingFee staMeetingFee, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param staMeetingFee 查询条件
     * @return 总行数
     */
    long count(StaMeetingFee staMeetingFee);

    /**
     * 新增数据
     *
     * @param staMeetingFee 实例对象
     * @return 影响行数
     */
    int insert(StaMeetingFee staMeetingFee);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<StaMeetingFee> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<StaMeetingFee> entities);

    /**
     * 修改数据
     *
     * @param staMeetingFee 实例对象
     * @return 影响行数
     */
    int update(StaMeetingFee staMeetingFee);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除会议费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入会议费
     *
     * @param entities
     * @return
     */
    int insertBatch(@Param("entities") List<StaMeetingFee> entities);

    /**
     * 获取会议费列表
     *
     * @return
     */
    List<StaMeetingFee> getHyfList(Integer zb);

    List<StaMeetingFee> queryByKyfh(String kyfh);

    /**
     * 项目报表（会议费）查询
     *
     * @param XMMC 项目名称
     * @param HYDD 会议地点
     * @param QSRQ 创建起始日期
     * @param JZRQ 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchMeetingCost(Map map);
}
