package com.liang.dao;

import com.liang.entity.StaOutPay;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 外委合同支付(StaOutPayDao)表数据库访问层
 */
public interface StaOutPayDao {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaOutPay queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param staOutPay 查询条件
     * @param pageable  分页对象
     * @return 对象列表
     */
    List<StaOutPay> queryAllByLimit(StaOutPay staOutPay, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param staOutPay 查询条件
     * @return 总行数
     */
    long count(StaOutPay staOutPay);

    /**
     * 新增数据
     *
     * @param staOutPay 实例对象
     * @return 影响行数
     */
    int insert(StaOutPay staOutPay);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<StaOutPay> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<StaOutPay> entities);

    /**
     * 修改数据
     *
     * @param staOutPay 实例对象
     * @return 影响行数
     */
    int update(StaOutPay staOutPay);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除外委合同
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入外委合同支付
     *
     * @param entities
     * @return
     */
    int insertBatch(@Param("entities") List<StaOutPay> entities);

    /**
     * 获取外委合同支付列表
     *
     * @return
     */
    List<StaOutPay> getWwhtList(Integer zb);

    /**
     * 查询全部外委合同支付费用
     *
     * @return
     */
    List<HashMap<String, String>> getAllOutPay();
}
