package com.liang.dao;

import com.liang.entity.StaBudgetapproval;
import com.liang.entity.StaPrintingFee;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 会议费(StaPrintingFee)表数据库访问层
 */
public interface StaPrintingFeeDao {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaPrintingFee queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param staPrintingFee 查询条件
     * @param pageable       分页对象
     * @return 对象列表
     */
    List<StaPrintingFee> queryAllByLimit(StaPrintingFee staPrintingFee, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param staPrintingFee 查询条件
     * @return 总行数
     */
    long count(StaPrintingFee staPrintingFee);

    /**
     * 新增数据
     *
     * @param staPrintingFee 实例对象
     * @return 影响行数
     */
    int insert(StaPrintingFee staPrintingFee);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<StaPrintingFee> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<StaPrintingFee> entities);

    /**
     * 修改数据
     *
     * @param staPrintingFee 实例对象
     * @return 影响行数
     */
    int update(StaPrintingFee staPrintingFee);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除打印费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入打印费
     *
     * @param entities
     * @return
     */
    int insertBatch(@Param("entities") List<StaPrintingFee> entities);

    /**
     * 获取打印费列表
     *
     * @return
     */
    List<StaPrintingFee> getDyfList(Integer zb);

    //获取打印费列表
    List<StaPrintingFee> queryBySqkyfh(String sqkyfh);

    /**
     * 项目报表(打印费)查询
     *
     * @param MC   项目名称
     * @param QSRQ 创建起始日期
     * @param JZRQ 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchPrintingCost(Map map);
}
