package com.liang.dao;

import com.liang.entity.StaSourceFee;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 资料费(StaSourceFee)表数据库访问层
 */
public interface StaSourceFeeDao {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaSourceFee queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param staSourceFee 查询条件
     * @param pageable     分页对象
     * @return 对象列表
     */
    List<StaSourceFee> queryAllByLimit(StaSourceFee staSourceFee, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param staSourceFee 查询条件
     * @return 总行数
     */
    long count(StaSourceFee staSourceFee);

    /**
     * 新增数据
     *
     * @param staSourceFee 实例对象
     * @return 影响行数
     */
    int insert(StaSourceFee staSourceFee);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<StaSourceFee> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<StaSourceFee> entities);

    /**
     * 修改数据
     *
     * @param staSourceFee 实例对象
     * @return 影响行数
     */
    int update(StaSourceFee staSourceFee);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除资料费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入资料费
     *
     * @param entities
     * @return
     */
    int insertBatch(@Param("entities") List<StaSourceFee> entities);

    List<StaSourceFee> queryByKyfh(String kyfh);

    /**
     * 获取资料费列表
     *
     * @return
     */
    List<StaSourceFee> getZlfList(Integer zb);

    /**
     * 项目报表（资料费）查询
     *
     * @param MC   项目名称
     * @param TSMC 图书美年广场
     * @param CBS  出版社
     * @param QSRQ 创建起始日期
     * @param JZRQ 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchSourceCost(Map map);

    List<StaSourceFee> searchSourceTsmcByDeptName(String deptName);
}
