package com.liang.service;

import com.liang.entity.StaMaterial;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 材料费(StaMaterial)表服务接口
 */
public interface StaMaterialService {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaMaterial queryById(Integer id);

    /**
     * 分页查询
     *
     * @param staMaterial 筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    Page<StaMaterial> queryByPage(StaMaterial staMaterial, PageRequest pageRequest);

    /**
     * 新增数据
     *
     * @param staMaterial 实例对象
     * @return 实例对象
     */
    int insert(StaMaterial staMaterial);

    /**
     * 修改数据
     *
     * @param staMaterial 实例对象
     * @return 实例对象
     */
    int update(StaMaterial staMaterial);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    boolean deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除材料费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入材料费
     *
     * @param expenseList
     * @return
     */
    int insertBatch(List<StaMaterial> expenseList);

    /**
     * 获取材料费列表
     *
     * @return
     */
    List<StaMaterial> getList(Integer zb);

    /**
     * 统计报表（材料费）查询
     *
     * @param mc   项目名称
     * @param clmc 材料名称
     * @param wlbm 物料编码
     * @param bz   备注
     * @param qsrq 创建起始日期
     * @param jzrq 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchMaterialCost(Map map);
}
