package com.liang.service;

import com.liang.entity.StaSourceFee;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 资料费(StaSourceFee)表服务接口
 */
public interface StaSourceFeeService {
    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    StaSourceFee queryById(Integer id);

    /**
     * 分页查询
     *
     * @param staSourceFee 筛选条件
     * @param pageRequest  分页对象
     * @return 查询结果
     */
    Page<StaSourceFee> queryByPage(StaSourceFee staSourceFee, PageRequest pageRequest);

    /**
     * 新增数据
     *
     * @param staSourceFee 实例对象
     * @return 实例对象
     */
    int insert(StaSourceFee staSourceFee);

    /**
     * 修改数据
     *
     * @param staSourceFee 实例对象
     * @return 实例对象
     */
    int update(StaSourceFee staSourceFee);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    boolean deleteById(Integer id);

    /**
     * 通过主表删除数据
     *
     * @param zb
     * @return
     */
    int deleteByZb(Integer zb);

    /**
     * 批量删除资料费
     *
     * @param zbList
     * @return
     */
    int batchDeleteByZb(List<Integer> zbList);

    /**
     * 批量插入资料费
     *
     * @param expenseList
     * @return
     */
    int insertBatch(List<StaSourceFee> expenseList);

    /**
     * 获取资料费列表
     *
     * @return
     */
    List<StaSourceFee> getZlfList(Integer zb);


    List<StaSourceFee> queryByKyfh(String kyfh);

    /**
     * 项目报表（资料费）查询
     *
     * @param mc   项目名称
     * @param tsmc 图书美年广场
     * @param cbs  出版社
     * @param qsrq 创建起始日期
     * @param jzrq 创建结束日期
     * @return
     */
    List<HashMap<String, Object>> searchSourceCost(Map map);

    List<StaSourceFee> searchSourceTsmcByDeptName(String deptName);
}
