package com.liang.service.impl;

import com.liang.dao.StaOutPayDao;
import com.liang.entity.StaOutPay;
import com.liang.service.StaOutPayService;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;

/**
 * 外委合同支付(StaOutPayServiceImpl)表服务实现类
 */
@Service("staOutPayService")
public class StaOutPayServiceImpl implements StaOutPayService {
    @Resource
    private StaOutPayDao staOutPayDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public StaOutPay queryById(Integer id) {
        return this.staOutPayDao.queryById(id);
    }

    /**
     * 分页查询
     *
     * @param staOutPay   筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    @Override
    public Page<StaOutPay> queryByPage(StaOutPay staOutPay, PageRequest pageRequest) {
        long total = this.staOutPayDao.count(staOutPay);
        return new PageImpl<>(this.staOutPayDao.queryAllByLimit(staOutPay, pageRequest), pageRequest, total);
    }

    /**
     * 新增数据
     *
     * @param staOutPay 实例对象
     * @return 实例对象
     */
    @Override
    public int insert(StaOutPay staOutPay) {
        return this.staOutPayDao.insert(staOutPay);
    }

    /**
     * 修改数据
     *
     * @param staOutPay 实例对象
     * @return 实例对象
     */
    @Override
    public int update(StaOutPay staOutPay) {
        return this.staOutPayDao.update(staOutPay);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer id) {
        return this.staOutPayDao.deleteById(id) > 0;
    }

    @Override
    public int deleteByZb(Integer zb) {
        return this.staOutPayDao.deleteByZb(zb);
    }

    @Override
    public int batchDeleteByZb(List<Integer> zbList) {
        return this.staOutPayDao.batchDeleteByZb(zbList);
    }

    @Override
    public int insertBatch(List<StaOutPay> expenseList) {
        return this.staOutPayDao.insertBatch(expenseList);
    }

    @Override
    public List<StaOutPay> getWwhtList(Integer zb) {
        return this.staOutPayDao.getWwhtList(zb);
    }

    @Override
    public List<HashMap<String, String>> getAllOutPay() {
        return this.staOutPayDao.getAllOutPay();
    }
}
