package com.liang.service.impl;

import com.liang.entity.SysDictInfo;
import com.liang.dao.SysDictInfoDao;
import com.liang.service.SysDictInfoService;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * (SysDictInfo)表服务实现类
 *
 * @author makejava
 * @since 2023-02-25 22:29:47
 */
@Service("sysDictInfoService")
public class SysDictInfoServiceImpl implements SysDictInfoService {
    @Resource
    private SysDictInfoDao sysDictInfoDao;

    /**
     * 通过ID查询单条数据
     *
     * @param dictId 主键
     * @return 实例对象
     */
    @Override
    public SysDictInfo queryById(String dictId) {
        return this.sysDictInfoDao.queryById(dictId);
    }

    /**
     * 分页查询
     *
     * @param sysDictInfo 筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    @Override
    public Page<SysDictInfo> queryByPage(SysDictInfo sysDictInfo, PageRequest pageRequest) {
        long total = this.sysDictInfoDao.count(sysDictInfo);
        return new PageImpl<>(this.sysDictInfoDao.queryAllByLimit(sysDictInfo, pageRequest), pageRequest, total);
    }

    /**
     * 新增数据
     *
     * @param sysDictInfo 实例对象
     * @return 实例对象
     */
    @Override
    public SysDictInfo insert(SysDictInfo sysDictInfo) {
        this.sysDictInfoDao.insert(sysDictInfo);
        return sysDictInfo;
    }

    /**
     * 修改数据
     *
     * @param sysDictInfo 实例对象
     * @return 实例对象
     */
    @Override
    public SysDictInfo update(SysDictInfo sysDictInfo) {
        this.sysDictInfoDao.update(sysDictInfo);
        return this.queryById(sysDictInfo.getDictId());
    }

    /**
     * 通过主键删除数据
     *
     * @param dictId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(String dictId) {
        return this.sysDictInfoDao.deleteById(dictId) > 0;
    }

    @Override
    public List<Map<String, String>> queryByCode(String dictCode) {
        return this.sysDictInfoDao.queryByCode(dictCode);
    }

    /**
     * 获取指定的枚举Map
     *
     * @param dictCode 字典编码
     * @return
     */
    @Override
    public Map<String, String> getDictMap(String dictCode) {
        if (StringUtils.isBlank(dictCode)) {
            return null;
        }
        Map<String, String> result = new HashMap<>();
        List<Map<String, String>> dictList = this.sysDictInfoDao.queryByCode(dictCode);
        if (!CollectionUtils.isEmpty(dictList)) {
            for (int i = 0; i < dictList.size(); i++) {
                Map<String, String> tempMap = dictList.get(i);
                String K = tempMap.get("code");
                String V = tempMap.get("name");
                result.put(K, V);
            }
        }
        return result;
    }

}
